@@ -3,20 +3,21 @@
 
     Copyright (c) 1999, 2000 Chris Schlaeger <cs@kde.org>
 
-    This program is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public
-    License version 2 or at your option version 3 as published by
-    the Free Software Foundation.
+ This program is free software; you can redistribute it and/or
+ modify it under the terms of the GNU General Public License as
+ published by the Free Software Foundation; either version 2 of
+ the License or (at your option) version 3 or any later version
+ accepted by the membership of KDE e.V. (or its successor approved
+ by the membership of KDE e.V.), which shall act as a proxy 
+ defined in Section 14 of version 3 of the license.
 
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ This program is distributed in the hope that it will be useful,
+ but WITHOUT ANY WARRANTY; without even the implied warranty of
+ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ GNU General Public License for more details.
 
+ You should have received a copy of the GNU General Public License
+ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 #include <kapplication.h>
@@ -123,15 +124,13 @@ HostConnector::HostConnector( QWidget *parent, const char *name )
 
   layout->addWidget( group, 1, 0, 1, 2 );
 
-  connect( mUseCustom, SIGNAL(toggled(bool)),
-           mCommands, SLOT(setEnabled(bool)) );
-  connect( mUseDaemon, SIGNAL(toggled(bool)),
-           mPort, SLOT(setEnabled(bool)) );
+  connect(mUseCustom, &QRadioButton::toggled, mCommands, &KComboBox::setEnabled);
+  connect(mUseDaemon, &QRadioButton::toggled, mPort, &KIntSpinBox::setEnabled);
   connect( mHostNames->lineEdit(),  SIGNAL(textChanged(QString)),
            this, SLOT(slotHostNameChanged(QString)) );
   enableButtonOk( !mHostNames->lineEdit()->text().isEmpty() );
   KAcceleratorManager::manage( this );
-  connect(this,SIGNAL(helpClicked()),this,SLOT(slotHelp()));
+  connect(this, &HostConnector::helpClicked, this, &HostConnector::slotHelp);
 }
 
 HostConnector::~HostConnector()
@@ -227,4 +226,4 @@ void HostConnector::slotHelp()
   KHelpClient::invokeHelp( "connectingtootherhosts", "ksysguard" );
 }
 
-#include "HostConnector.moc"
+
